@@ -271,7 +271,7 @@ class SwerveDrivetrain(Subsystem):
             )
         )
 
-        self.odometry.update(Rotation2d(self.gyro.get_robot_heading()), *self.swerve_positions)
+        self.odometry.update(Rotation2d(self.gyro.get_robot_heading()), self.swerve_positions)
         self.odometry_estimator.update(Rotation2d(self.gyro.get_robot_heading()), *self.swerve_positions)
         self.chassis_speeds = self.kinematics.toChassisSpeeds(*module_states)
 
